ednx.fipp


pprintclj

(pprint data)
(pprint data opts)

Pretty print data using fipp.clojure/pprint opts is a map of options to pass to fipp.clojure/pprint it is uses additional fipp-edn-writers/readers managed in ednx.handler

Pretty print data using fipp.clojure/pprint
opts is a map of options to pass to fipp.clojure/pprint
it is uses additional fipp-edn-writers/readers managed in ednx.handler
raw docstring

spit-fippclj

(spit-fipp filename data)
(spit-fipp filename data opts)

spit-fipp-commentclj

(spit-fipp-comment file-name data comment)
(spit-fipp-comment file-name data comment opts)

cljdoc builds & hosts documentation for Clojure/Script libraries